An integer scalar rank parameter for the test, from 1 through 12.
This is often the difference in cointegration rank.
iscon
An indicator that there is a constant intercept
term in the model.
dir_name
A string name of directory in which the approximating tables
are stored. This is not normally used, since sufficient tables are included in the package.
However, a user might want to draw the tables from another location.
bb
The fractional integration parameter, which can take on values
between 0.5 and 2.0.
stat
A numeric scalar value of the test statistic.
Value
A numeric scalar P-value.
References
James G. MacKinnon and Morten <U+00D8>rregaard Nielsen,
"Numerical Distribution Functions of Fractional Unit Root and Cointegration Tests,"
Journal of Applied Econometrics, Vol. 29, No. 1, 2014, pp.161-171.
See Also
Calls fpval for the calculation of P-values after
performing some intermediate calculations.