get_fracdist_tab selects a table of probabilities
and quantiles for a list of values of the fractional
integration parameter, corresponding to a particular rank
or dimension and the specification of a constant term.
get_fracdist_tab(iq, iscon, dir_name = NULL, file_ext = "rda")An integer scalar rank parameter for the test, from 1 through 12. This is often the difference in cointegration rank.
An indicator that there is a constant intercept term in the model.
A string name of directory in which the tables are stored. This is not normally used, however, a user might want to draw the tables from another location.
A string extension indicating the file format of
the tables. The default is 'rda', which is the format of
the tables included in the package. The tables may also be stored in
'RData' format. The tables accompanying the
original Fortran program, on which this package is based,
can be obtained in 'txt' format. See the reference for details.
A data frame with three columns: bbb is the fractional
integration parameter, probs are the probability values,
and xndf is the probs quantile of the distribution.
James G. MacKinnon and Morten <U+00D8>rregaard Nielsen, "Numerical Distribution Functions of Fractional Unit Root and Cointegration Tests," Journal of Applied Econometrics, Vol. 29, No. 1, 2014, pp.161-171.
# NOT RUN {
frtab <- get_fracdist_tab(iq = 1, iscon = 0)
# }
Run the code above in your browser using DataLab